@@ -772,38 +772,38 @@ connections</source>
 <context>
     <name>MainWindowExt</name>
     <message>
-        <location filename="MainWindowExt.py" line="38"/>
+        <location filename="MainWindowExt.py" line="37"/>
         <source>Daemon QNetMan is not running.
 Start daemons now ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="39"/>
+        <location filename="MainWindowExt.py" line="38"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="44"/>
+        <location filename="MainWindowExt.py" line="43"/>
         <source>Information</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="45"/>
+        <location filename="MainWindowExt.py" line="44"/>
         <source>Please restart the program now.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="48"/>
+        <location filename="MainWindowExt.py" line="47"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="49"/>
+        <location filename="MainWindowExt.py" line="48"/>
         <source>Failed to start daemon.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="52"/>
+        <location filename="MainWindowExt.py" line="51"/>
         <source>Features will be limited.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1024,85 +1024,85 @@ Start daemons now ?</source>
 <context>
     <name>WinNetStatProcExt</name>
     <message>
-        <location filename="WinNetStatProcExt.py" line="373"/>
+        <location filename="WinNetStatProcExt.py" line="375"/>
         <source>Refresh interval:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="374"/>
+        <location filename="WinNetStatProcExt.py" line="376"/>
         <source>sec</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="387"/>
+        <location filename="WinNetStatProcExt.py" line="389"/>
         <source>Please, wait...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="403"/>
+        <location filename="WinNetStatProcExt.py" line="405"/>
         <source>Info</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="417"/>
+        <location filename="WinNetStatProcExt.py" line="419"/>
         <source>Back</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="461"/>
+        <location filename="WinNetStatProcExt.py" line="463"/>
         <source>The device has received a connection request and send the acknowledgment. At the moment, is expected to start the connection.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="464"/>
+        <location filename="WinNetStatProcExt.py" line="466"/>
         <source>The &quot;steady state&quot; of an open TCP connection. Data can be exchanged freely once both devices in the connection enter this state. This will continue until the connection is closed.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="345"/>
+        <location filename="WinNetStatProcExt.py" line="347"/>
         <source>Information is not available</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="453"/>
+        <location filename="WinNetStatProcExt.py" line="455"/>
         <source>Device (normally a server) is waiting for client connection</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="458"/>
+        <location filename="WinNetStatProcExt.py" line="460"/>
         <source>Device (normally a client) sent a request to connect to another device and is waiting for confirmation (normally from a server).</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="467"/>
+        <location filename="WinNetStatProcExt.py" line="469"/>
         <source>One of the stages of closing the connection. Connection closing sent the request to the remote device.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="470"/>
+        <location filename="WinNetStatProcExt.py" line="472"/>
         <source>The last stage of closing the connection. Connection closing sent the request to the remote device.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="476"/>
+        <location filename="WinNetStatProcExt.py" line="478"/>
         <source>One of the stages of closing the connection. Connection closing sent the request to the local device.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="482"/>
-        <source>The last stage of closing the connection. After wait period, the device pass to the CLOSED state.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WinNetStatProcExt.py" line="485"/>
+        <location filename="WinNetStatProcExt.py" line="487"/>
         <source>This is the state by default before the connection is established. This is the sitation when there is no any connection between devices : it eather hasn&apos;t been created yet, or has just been broken.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="479"/>
+        <location filename="WinNetStatProcExt.py" line="481"/>
         <source>One of the stages of closing the connection. The simultaneous closure of the connection.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="WinNetStatProcExt.py" line="484"/>
+        <source>The last stage of closing the connection. After wait period, the connection pass to the CLOSED state.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>dlgNetworkSelect</name>
