@@ -81,8 +81,10 @@ class DialogRecordManagerExt(Ui_DialogRecordManager, QtCore.QObject):
 		name_iface = item.text()
 		
 #TODO: Изменить код на ускорение реакции кнопки
-		type_iface = self.my_db.getTypeByIface( name_iface )
-		self.my_db.autoRecEnable( type_iface, checked )
+
+		##Эта операция перенесена в демона
+		##type_iface = self.my_db.getTypeByIface( name_iface )
+		##self.my_db.autoRecEnable( type_iface, checked )
 
 		if self.prevState_recNow[ name_iface ] != checked:
 			if checked:
