@@ -49,6 +49,11 @@ class ListSessionsExt( QtGui.QMainWindow ):
 		self.actionForm()
 
 	def actionForm(self):
+		self.lblLoading = QtGui.QLabel( self )
+		self.lblLoading.setGeometry(QtCore.QRect(630, 30, 140, 30))
+		self.lblLoading.setObjectName("lblLoading")
+		self.lblLoading.setText(QtGui.QApplication.translate("ListSessionsExt", "Loading...", None, QtGui.QApplication.UnicodeUTF8))
+		
 		self.ui.listWidgetSessions.itemClicked.connect( self.clickedItem )
 		self.ui.listWidgetSessions.itemChanged.connect( self.itemChanged )
 		self.ui.pBVSelectedAll.clicked.connect( self.selectedAllItems )
@@ -192,6 +197,9 @@ class ListSessionsExt( QtGui.QMainWindow ):
 
 
 	def initItemsSession(self, startTime = None, endTime = None, filterType = 0):
+		
+		self.lblLoading.show()
+		
 		#параметры включеного фильтра
 		self.startTime_filter = startTime
 		self.endTime_filter = endTime
@@ -246,6 +254,8 @@ class ListSessionsExt( QtGui.QMainWindow ):
 		if len(self.ui.listWidgetSessions.selectedItems()) == 0:
 			self.ui.pBViewItem.setEnabled( False )
 			self.itemChanged()
+		
+		self.lblLoading.hide()
 
 
 	def viewSession(self):
