@@ -6,7 +6,6 @@ from ViewCurrentSessionExt import ViewCurrentSessionExt
 from OptionsWindowExt import OptionsWindowExt
 from ListSessionsExt import ListSessionsExt
 from WinAboutExt import WinAboutExt
-#from WinNetStatExt import WinNetStatExt
 from WinNetStatProcExt import WinNetStatExt
 from QNMDBusClient import QNMDBusClient
 
@@ -60,15 +59,12 @@ class MainWindowExt( QtGui.QMainWindow ):
 		self.windowRealTime = ViewCurrentSessionExt( self, self.db, self.mydbus, self.qset )
 		self.windowRealTime.hide()
 		
-
-		self.windowOptions = OptionsWindowExt( self, self.db, self.mydbus )
-		self.windowOptions.hide()
+		self.windowOptions = None
 
 		self.windowAbout = WinAboutExt( self )
 		self.windowAbout.hide()
 		
-		self.windowConnections = WinNetStatExt( self )
-		self.windowConnections.hide()
+		self.windowConnections = None
 
 		self.actionForm()
 
@@ -91,11 +87,14 @@ class MainWindowExt( QtGui.QMainWindow ):
 		self.windowListSessions.activateFilter()
 
 	def showOptions(self):
+		if self.windowOptions == None:
+			self.windowOptions = OptionsWindowExt( self, self.db, self.mydbus )
 		self.windowOptions.show()
 
 	def showConnections(self):
+		if self.windowConnections == None:
+			self.windowConnections = WinNetStatExt( self, self.qset )
 		self.windowConnections.show()
-		#self.windowConnections.showData()
 	
 
 	def daemonStart(self):
