@@ -27,6 +27,9 @@ class QNMSettings(QtCore.QSettings):
 		self.key_timestamp_s = "timestamp"
 		self.key_zoom_s = "zoom"
 
+		self.groupNetStat = "netstat"
+		self.key_autorefresh_ns = "autorefresh"
+
 	#----------------------------------#
 	def setTypeGraphStat( self ):
 		self.beginGroup( self.groupMonitorOpt )
@@ -283,3 +286,19 @@ class QNMSettings(QtCore.QSettings):
 		self.endGroup()
 		val = (int)(val)
 		return val
+	
+	
+	#===============================================================#
+	def setRefreshInterval_ns(self, seconds):
+		self.beginGroup( self.groupNetStat )
+		self.setValue(self.key_autorefresh_ns, seconds)
+		self.endGroup()
+
+	def refreshInterval_ns(self):
+		self.beginGroup( self.groupNetStat )
+		val = self.value( self.key_autorefresh_ns, "30" )
+		self.endGroup()
+		val = (int)(val)
+		return val
+
+	#----------------------------------#
