@@ -50,7 +50,7 @@ class NetStatProc( QtCore.QThread ):
 
 
 class WinNetStatExt( QtGui.QMainWindow ):
-	def __init__(self, parent = None):
+	def __init__(self, parent, qset ):
 		QtGui.QMainWindow.__init__( self, parent )
 		self.parent = parent
 		
@@ -62,6 +62,8 @@ class WinNetStatExt( QtGui.QMainWindow ):
 			pass
 			#print "WinNetStatExt::__init__(): Exception setAttribute():" , e
 
+		self.qset = qset
+
 		self.flResolv = False
 		self.data = list()
 
@@ -191,7 +193,7 @@ class WinNetStatExt( QtGui.QMainWindow ):
 		self.listAnimPixmap.append( icon )
 		self.indxAnim = 0
 		
-		self.timeoutAutoRefresh = 30000 # 30 sec
+		self.timeoutAutoRefresh = self.qset.refreshInterval_ns()
 		self.timerAutoRefresh = QtCore.QTimer()
 		QtCore.QObject.connect( self.timerAutoRefresh, QtCore.SIGNAL("timeout()"), self.doAutoRefreshData )
 
@@ -368,10 +370,10 @@ class WinNetStatExt( QtGui.QMainWindow ):
 
 	def autoRefreshData(self, checked):
 		if checked:
-			self.timerAutoRefresh.start( self.timeoutAutoRefresh )
+			self.timerAutoRefresh.start( self.timeoutAutoRefresh*1000 )
 			txt1 = QtGui.QApplication.translate("WinNetStatProcExt", "Refresh interval:", None, QtGui.QApplication.UnicodeUTF8)
 			txt2 = QtGui.QApplication.translate("WinNetStatProcExt", "sec", None, QtGui.QApplication.UnicodeUTF8)
-			self.noti.notify( "%s %s %s"%(txt1, (self.timeoutAutoRefresh/1000), txt2) )
+			self.noti.notify( "%s %s %s"%(txt1, self.timeoutAutoRefresh, txt2) )
 		else:
 			self.timerAutoRefresh.stop()
 	
@@ -478,7 +480,7 @@ class WinNetStatExt( QtGui.QMainWindow ):
 			txt = QtGui.QApplication.translate("WinNetStatProcExt", "One of the stages of closing the connection. The simultaneous closure of the connection.", None, QtGui.QApplication.UnicodeUTF8)
 			self.ui_procInfo.lblDescrText.setPlainText( txt )
 		elif state == 'TIME_WAIT':
-			txt = QtGui.QApplication.translate("WinNetStatProcExt", "The last stage of closing the connection. After wait period, the device pass to the CLOSED state.", None, QtGui.QApplication.UnicodeUTF8)
+			txt = QtGui.QApplication.translate("WinNetStatProcExt", "The last stage of closing the connection. After wait period, the connection pass to the CLOSED state.", None, QtGui.QApplication.UnicodeUTF8)
 			self.ui_procInfo.lblDescrText.setPlainText( txt )
 		elif state == 'CLOSE':
 			txt = QtGui.QApplication.translate("WinNetStatProcExt", "This is the state by default before the connection is established. This is the sitation when there is no any connection between devices : it eather hasn't been created yet, or has just been broken.", None, QtGui.QApplication.UnicodeUTF8)
@@ -582,7 +584,8 @@ class WinNetStatExt( QtGui.QMainWindow ):
 		self.ui_dlg.lWinterval.itemClicked.disconnect( self.setRefreshInterval )
 		self.dlg.hide()
 		txt = split(indx.text(), ' ')
-		self.timeoutAutoRefresh = ((int)(txt[0]))*1000
+		self.timeoutAutoRefresh = int( "%s"%txt[0], 10 )
 		if self.timerAutoRefresh.isActive():
 			self.timerAutoRefresh.stop()
-			self.timerAutoRefresh.start( self.timeoutAutoRefresh )
+			self.timerAutoRefresh.start( (self.timeoutAutoRefresh*1000) )
+		self.qset.setRefreshInterval_ns( self.timeoutAutoRefresh )
